@@ -12,23 +12,24 @@
 #
 ##############################################################################
 """
-$Id: provider.py 72087 2007-01-18 01:03:33Z rogerineichen $
+$Id: provider.py 80207 2007-09-27 09:02:03Z zagy $
 """
 
-import zope.interface
 import zope.component
-from zope.publisher.interfaces import browser
+import zope.interface
+import zope.publisher.interfaces.browser
 
-from z3c.pagelet import interfaces
+import z3c.pagelet.interfaces
 
 
 class PageletRenderer(object):
     """Render the adapted pagelet."""
 
-    zope.interface.implements(interfaces.IPageletRenderer)
+    zope.interface.implements(z3c.pagelet.interfaces.IPageletRenderer)
 
-    zope.component.adapts(zope.interface.Interface, browser.IBrowserRequest,
-        interfaces.IPagelet)
+    zope.component.adapts(zope.interface.Interface,
+                          zope.publisher.interfaces.browser.IBrowserRequest,
+                          z3c.pagelet.interfaces.IPagelet)
 
     def __init__(self, context, request, pagelet):
         self.__updated = False
